unit DemoFrm;

interface

uses
  {$IFDEF VER90}
  OleAuto,
  {$ENDIF}
  {$IFDEF VER100}
  ComObj,
  {$ENDIF}
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ExtCtrls,
  OleanderTools, OleanderException, OleanderAuto, OleanderIdentifier,
  OleanderPrinter, OleanderController, OleanderWord7, OleanderWord8,
  DB, DBTables, DBCtrls, ComCtrls, Grids, DBGrids, Buttons;


type
  TfrmDemo = class(TForm)
    sbrCount: TStatusBar;
    pnlOptions: TPanel;
    lblDocument: TLabel;
    lblPrinter: TLabel;
    cbxPrinter: TComboBox;
    olcController: TOleanderController;
    olpWord7: TOleanderWord7;
    pnlGrid: TPanel;
    dbnDemo: TDBNavigator;
    dbgDemo: TDBGrid;
    olpWord8: TOleanderWord8;
    btnClose: TBitBtn;
    btnStart: TBitBtn;
    btnAbort: TBitBtn;
    pnlIdentifiers: TPanel;
    gbxDocidentifiers: TGroupBox;
    lbxDocumentIdentifiers: TListBox;
    gbxAvailableIdentifiers: TGroupBox;
    lbxAvailableIdentifiers: TListBox;
    gbxOptions: TGroupBox;
    chkShowserver: TCheckBox;
    chkPreview: TCheckBox;
    chkReadonly: TCheckBox;
    lblServer: TLabel;
    cbxServer: TComboBox;
    cbxDocument: TComboBox;
    procedure btnStartClick(Sender: TObject);
    procedure btnAbortClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure cbxPrinterChange(Sender: TObject);
    procedure olcControllerIdentifierCheck(sender: TObject;
      const AIdentifier: TOleanderIdentifier; var AOk: Boolean);
    procedure olcControllerIdentifierValue(sender: TObject;
      const AIdentifier: TOleanderIdentifier; var AValue: string);
    procedure cbxServerChange(Sender: TObject);
    procedure olcControllerOpen(Sender: TObject);
    procedure olcControllerAfterPrintField(Sender: TObject;
      AIdentifier: TOleanderIdentifier; ADatasource: TDataSource);
    procedure chkShowserverClick(Sender: TObject);
    procedure cbxDocumentChange(Sender: TObject);
    procedure olcControllerAfterPrintRecord(Sender: TObject;
      AIdentifier: TOleanderIdentifier; ADatasource: TDataSource);
    procedure chkReadonlyClick(Sender: TObject);
  private
  protected
    oleserver: TOleanderPrinter;
    abortserver: boolean;
    counter: integer;
  public
    { Public declarations }
  end;

implementation

{$R *.DFM}

CONST
  IDCONTROLLER = 'OLEANDERCONTROLLERVERSION';
  IDPRINTER    = 'OLEANDERPRINTERVERSION';

procedure TfrmDemo.btnStartClick(Sender: TObject);
var
  i: integer;
begin
  try
    screen.cursor := crHourglass;
    try
      counter := 0;
      btnStart.Enabled := FALSE;
      btnAbort.Enabled := TRUE;

      olcController.Bookmarks.Clear;
      for i := 0 to dbgDemo.SelectedRows.Count - 1 do
        olcController.Bookmarks.Add(PString(dbgDemo.SelectedRows.Items[i]));

      abortserver := FALSE;
      olcController.Print(chkPreview.Checked);
      olcController.Check;
      screen.cursor := crDefault;
      while chkPreview.Checked and (not abortserver) do Application.ProcessMessages;
    except
      on e : Exception do
        MessageDlg(e.message, mtWarning, [mbOk], 0);
    end;
  finally
    screen.cursor := crDefault;
    btnStart.Enabled := TRUE;
    btnAbort.Enabled := FALSE;
    olcController.Close;
  end;
end;

procedure TfrmDemo.btnAbortClick(Sender: TObject);
begin
  abortserver := TRUE;
end;

procedure TfrmDemo.FormCreate(Sender: TObject);
begin
  cbxPrinter.Items.Assign(RegistryPrinterNames);
end;

procedure TfrmDemo.cbxPrinterChange(Sender: TObject);
begin
  if oleserver is TOleanderWord7 then
    case TOleanderWord7(oleserver).WordbasicDialect of
      wbdGerman : oleserver.Printername := MapWord7Printer(cbxPrinter.Text, ' an ');
      wbdEnglish: oleserver.Printername := MapWord7Printer(cbxPrinter.Text, ' on ');
    end
  else
    oleserver.Printername := cbxPrinter.Text;
end;

procedure TfrmDemo.olcControllerIdentifierCheck(Sender: TObject;
  const AIdentifier: TOleanderIdentifier; var AOk: Boolean);
begin
  AOk := (AIdentifier.Name = IDCONTROLLER) or (AIdentifier.Name = IDPRINTER);
end;

procedure TfrmDemo.olcControllerIdentifierValue(Sender: TObject;
  const AIdentifier: TOleanderIdentifier; var AValue: string);
begin
  if AIdentifier.Name = IDCONTROLLER then AValue := olcController.Version
  else if AIdentifier.Name = IDPRINTER then AValue := olcController.OleanderPrinter.Version;
end;

procedure TfrmDemo.cbxServerChange(Sender: TObject);
begin
  case cbxServer.ItemIndex of
    0 : begin
          oleserver := olpWord7;
          olpWord7.WordbasicDialect := wbdEnglish;
        end;
    1 : begin
          oleserver := olpWord7;
          olpWord7.WordbasicDialect := wbdGerman;
        end;
    2 : oleserver := olpWord8;
    else oleserver := NIL;
  end;
  olcController.OleanderPrinter := oleserver;
  lblDocument.Enabled := Assigned(oleserver);
  cbxDocument.Enabled := Assigned(oleserver);
end;

procedure TfrmDemo.olcControllerOpen(Sender: TObject);
var
  i : integer;
begin
  lbxAvailableIdentifiers.items.Clear;
  if Assigned(oleserver) then
    for i := 0 to olcController.AvailableIdentifiers.count-1 do
      lbxAvailableIdentifiers.items.Add(olcController.AvailableIdentifiers[i].Name);
  lbxAvailableIdentifiers.items.Add(IDCONTROLLER);
  lbxAvailableIdentifiers.items.Add(IDPRINTER);
end;

procedure TfrmDemo.olcControllerAfterPrintField(Sender: TObject;
  AIdentifier: TOleanderIdentifier; ADatasource: TDataSource);
begin
  sbrCount.panels[0].Text := IntToStr(olcController.OleanderPrinter.CharsInserted);
  if abortserver then OleanderAbort;
  Application.ProcessMessages;
end;

procedure TfrmDemo.chkShowserverClick(Sender: TObject);
begin
  if Assigned(oleserver) then
    oleserver.ShowServer := chkShowServer.Checked;
end;

procedure TfrmDemo.cbxDocumentChange(Sender: TObject);
var
  i: integer;
begin
  inherited;
  oleserver.DocName := Exepath + 'doc\'+ oleserver.DocName;
  if FileExists(oleserver.DocName) then
  try
    screen.cursor := crHourglass;
    if olcController.Active then olcController.Close;
    olcController.Open;
    olcController.Check;
    lbxDocumentIdentifiers.items.Clear;
    for i := 0 to oleserver.Identifiers.Count-1 do
      lbxDocumentIdentifiers.items.Add(oleserver.identifiers[i].AsString);
    btnStart.Enabled := TRUE;
  finally
    screen.cursor := crDefault;
  end
  else
    btnStart.Enabled := FALSE;
end;

procedure TfrmDemo.olcControllerAfterPrintRecord(Sender: TObject;
  AIdentifier: TOleanderIdentifier; ADatasource: TDataSource);
begin
  if ADatasource = olcController.Datasource then inc(counter);
  sbrCount.Panels[1].Text := 'Record: ' + IntToStr(counter);
end;

procedure TfrmDemo.chkReadonlyClick(Sender: TObject);
begin
  if Assigned(oleserver) then
    oleserver.DocReadonly := chkReadonly.Checked;
end;

end.


